@@ -1,9 +1,5 @@
 """API for transact_write_items"""
-from .errors import (  # noqa
-    ItemUnknownToTransactionError,
-    TableUnknownToTransactionError,
-    TransactionAttemptsOverrun,
-)
+from .errors import TableSchemaUnknownError, TransactionAttemptsOverrun  # noqa
 from .modify import delete, put  # noqa
 from .read import get, require  # noqa
 from .run import versioned_transact_write_items  # noqa
